****************************************************************************
*********                 ANALYZING THE DISTRIBUTIONAL             *********
*********                      EFFECT OF TRADE                     ********* 
****************************************************************************


* Data source: Madagascar's 2001 "Enqute Permanente des Mnages" (EPM).

	clear all
	set mem 300m
	set matsize 800
	graph drop _all


* Open database
	
	cd "$input/Chapter6/Datasets"
	use tariff_9501.dta, clear

********* IMPORT DATABASE *********


* 1. Using the svydes command, answer the following questions:
* a)  What is the total number of strata, units (communities in  
* 	the database), and households, in the sample? What type of 
* 	sample is this?

* Open the database
	use "EMS.dta", clear

* Specify the survey structure and save it
	svyset comm_id [pweight=weights], strata(strata_id)
	save "EMS_temp.dta", replace

* Get a description of the survey structure
	svydescribe

	* Accordingly: 
	* #Stratum = 12, #Units = 213 and #Obs = 29801      
* This is a one-stage clustered design with stratification
* In the household survey used here, the population was stratified 
* into groups according to the environment (urban/rural) and to the
* district. With six districts, the number of strata is twelve (you
* can verify this by using the survey description command svydes). 
* Then, in each stratum, clusters were defined according to communities.
* Among them, some were selected with a probability proportional to the 
* community's size. Finally, in each selected community, households were
* randomly selected. 

* b)	What is the average number of households per unit (community)?
	use "EMS.dta", clear
	levelsof comm_id, local(com)
     	foreach c of local com {
		egen tp_`c' = group(hhold) if comm_id == `c'
	}
	egen nrhhold = rowtotal(tp_*)
	drop tp_*
	svy: mean nrhhold
	* the average household per community is 6.38


* c) 	In which stratum is the smallest unit (community)? How many households
*	are in it?
	* In stratum 71, there is the smallest unit
	levelsof strata_id, local(strat)
     	foreach s of local strat {
		egen tp_`s' = group(comm_id) if strata_id == `s'
	}
	egen nr_comm = rowtotal(tp_*)
	drop tp_*

	bys strata_id: egen nrcomm = max(nr_comm) 
	egen comm_min = min(nrcomm)
	bys strata_id: gen id = _n
	list strata_id if nrcomm == comm_min & id == 1



* 2. Without taking account of the survey's design, assess the progressivity  
* or regressivity of Madagascar's tariff structure on the consumption side. 
* The steps are as follows:
* a) 	Calculate the weighted-average tariff for each household; call it 
*	c_tariff;

	* The consumption-weighted average tariff for each household is given by:
	* taubar_ = sum(w_ik*tau_k) for k = 1,...,n
	* where: w_ik is the share of good k in household i's income
	*	   tau_k is the tariff on good k

* Open the database
	use "EMS_temp.dta", clear

* Compute the share of good k in the household's expenditure
	sort hhold_id
	by hhold_id: gen tau = prod_exp/income
	label var tau "share of good in expenditure"

* Compute the consumption-weighted average tariff. Note: gen sum gives the 
* cumulative sum, while egen sum yields the total sum
	sort hhold_id
	by hhold_id: egen c_tariff = sum(tau * tariff)
	label var c_tariff "consumption-weighted average tariff"

* b) 	Generate centiles of the income distribution in the sample;
	xtile centile = income, nquantiles(100)

* c) 	Calculate the average of this consumption-weighted tariff for each 
*	centile using the command collapse c_tariff, by(centile)
	collapse(mean)c_tariff income, by(centile)
	label var c_tariff "Consumption-weighted tariff"
	label var income "Household income (percentile)

* d)	Regress this centile average on income using Stata's lowess command, 
*	using a bandwidth of 0.8;
	lowess c_tariff income, bwidth(0.8) title("Consumption Effects, Madagascar's Tariff")
	
	cd "$input/Chapter6/Exercises/Results"
	graph save "EMP_lowless_nosurvey.gph", replace

* e)	In view of the smoother regression curve, is Madagascar's tariff 
*	structure progressive or regressive on the consumption side?
	* Based on the shape of the curve, it is regressive tax, i.e. 
	* it decreases with income


* 3. 	Redo question 2 but taking into account the survey's design. What do 
*	you observe?

* a) 	Calculate the weighted-average tariff for each household; call it 
*	c_tariff;

* Open the database

	cd "$input/Chapter6/Datasets"
	use "EMS_temp.dta", clear

* Compute the share of good k in the household's expenditure
	sort hhold_id
	by hhold_id: gen tau = prod_exp/income
	label var tau "share of good in expenditure"

* Compute the consumption-weighted average tariff. Note: gen sum gives the 
* cumulative sum, while egen sum yields the total sum
	sort hhold_id
	by hhold_id: egen c_tariff = sum(tau * tariff)
	label var c_tariff "consumption-weighted average tariff"

* b) 	Generate centiles of the income distribution in the sample;
	* Create variable containing percentiles using the xtile Stata command
	xtile centile = income, nquantiles(100)

* c) 	Calculate the average of this consumption-weighted tariff for each 
*	centile;
	gen c_tariff_bar = .	
	label var c_tariff_bar "Consumption-weighted tariff"
	foreach j of numlist 1/100{ 
		quietly svy: mean c_tariff if centile == `j'
		matrix xbar = e(b)
		scalar xbar = xbar[1,1]
		replace c_tariff_bar = xbar if centile == `j'
	}	
	keep income c_tariff_bar
	duplicates drop
	label var income "Household income (percentile)

* d)	Regress this centile average on income using Stata's lowess command, 
*	using a bandwidth of 0.8;
	lowess c_tariff income, bwidth(0.8) title("Consumption Effects, Madagascar's Tariff")
	
	cd "$input/Chapter6/Exercises/Results"
	graph save "EMS_lowless_withsurvey.gph", replace
	
* e)	In view of the smoother regression curve, is Madagascar's tariff 
*	structure progressive or regressive on the consumption side?
	* Based on the shape of the curve, it is regressive tax, i.e. 
	* it decreases with income


* 4. 	Using the household expenditure data, determine which of the 81 goods
* 	in the database are necessities (income elasticity lower than one) and 
*	which ones are luxuries (income elasticity above one). [Hint: calculate 
*	average product weights by centiles and perform a simple regression of 
*	product weights on centiles for each product.]

* Open the database
*	use "EMS_temp.dta", clear
*
* Compute the share of good k in the household's expenditure, drop if there is 
* missing observations
*	sort hhold_id
*	by hhold_id: gen tau = prod_exp/income
*	label var tau "share of good in expenditure"
*	label var income "Household income (percentile)
*	drop if tau == .
*
* Compute the average product weighted by survey
*	xtile centile = income, nquantiles(100)
*	gen tau_bar = .	
*	label var tau_bar "Average share of good in expenditure"
*	levelsof prod_code, local(prd)
* 	foreach p of local prd {	
*		levelsof centile if prod_code == `p', local(ctl)
*		foreach c of local ctl{ 
*			quietly svy: mean tau if centile == `c' & prod_code == `p'
*			matrix xbar = e(b)
*			scalar xbar = xbar[1,1]
*			replace tau_bar = xbar if centile == `c' & prod_code == `p'
*		}
*	}
*
*	* Save the data file, to save time and not redo-it the computation
*	save "EMS_elasticity.dta", replace

* Re-do it but without weighted

	cd "$input/Chapter6/Datasets"

	use "EMS_temp.dta", clear
	sort hhold_id
	by hhold_id: gen tau = prod_exp/income
	label var tau "share of good in expenditure"
	label var income "Household income (percentile)
	drop if tau == .
	xtile centile = income, nquantiles(100)
	collapse(mean) tau income, by(prod_code prod_name centile)
	rename tau tau_bar


* Regress product weights on income. Make sure to have at least 2
* observations to have enough degrees of freedom
	*use "EMS_elasticity.dta", clear
	keep prod_code prod_name income centile tau_bar
	duplicates drop

	gen lnincome = log(income)
	gen lntau_bar = log(tau_bar + 0.0001)
	drop if lntau_bar == .
	bys prod_code: gen obs = _N
	drop if obs == 1

	gen inc_elast = .
	label var inc_elast "Income elasticity"
	levelsof prod_code if lntau_bar ~= ., local(prd)
 	foreach p of local prd {
		quietly regress lntau lnincome if prod_code == `p'
		*quietly regress tau income if prod_code == `p'
		matrix xbar = e(b)
		scalar xbar = xbar[1,1]
		replace inc_elast = xbar if prod_code == `p'
	}	

* Determine which goods are luxury goods and which ones are necessity goods
	gen prod_type = "Necessity good"
	replace prod_type = "Luxury good" if inc_elast > 1
	label var prod_type "Necessity or luxury goods"
	keep prod_name prod_type
	duplicates drop	
	sort prod_type prod_name
	
	cd "$input/Chapter6/Exercises/Results"
	outsheet using "EMS_TypeOfGoods.txt", replace


* 5. 	Using your findings in Questions 2-3 and in Question 4, suggest a trade-
*	policy reform. Assuming a budget-neutral tariff reform designed to bring
*	more equity in the system, on what products would you suggest to raise 
*	tariffs? On which ones would you suggest to cut them? 

	* Tariffs are degressive and thus affect more low income groups. So the 
	* policy should decrease tariffs for necessity goods and increase for 
	* luxury goods.

graph drop _all	
	
exit
exit
exit
